 import java.awt.*;
 import java.io.*;

public class Filebrowser extends Frame
{
  private List list;
  private TextField infoarea;
  private Panel buttons;
  private Button parent,close;
  private FilenameFilter filter;

  private File cwd;
  private File dir;
  private String[] entries;
  

//Create the GUI - list the initial directory.

public Filebrowser(String directory,FilenameFilter filter) throws IOException
{
  super("File Browser");

  Font f2 = new Font("Helvetica",1,12);
  Font f3 = new Font("TimesRoman",2,12);
  directory = System.getProperty("user.dir");
  String filename ="";

  this.setBackground(Color.white);

  this.filter = filter;
  list = new List(12,false);
  list.setBackground(Color.pink);
  list.setFont(f2);
  infoarea = new TextField();
  infoarea.setEditable(false);
  buttons = new Panel();
  parent = new Button("Directory up");
  parent.setFont(f3);
  parent.setBackground(Color.orange);
  close = new Button("Close");
   close.setFont(f3);
   close.setBackground(Color.yellow);
  buttons.add(parent);
  buttons.add(close);
  this.add("Center",list);
  this.add("South",infoarea);
  this.add("North",buttons);
  this.list_directory(directory);
  this.show_info(filename);
//  this.handleEvent(e);


  this.pack();
  this.show();

//list the initial directory.

// list_directory(directory);


}

//this method uses list() method to get all the entries in a directory and display them in a list component.

public void list_directory(String directory)throws IOException
{
//  System.out.println("directory : " + directory );
  File dir = new File(directory);

  if(!dir.isDirectory())

  throw new IllegalArgumentException("Filebrowser: no such directory");

  list.clear();

  cwd = dir;
  this.setTitle(directory);
  entries = cwd.list(filter);
  for(int i=0;i<entries.length;i++)
  list.addItem(entries[i]);

}


//this method uses various File methods to obtain info about a file or a dir and displays the info in a Textfield

public void show_info(String filename) throws IOException
{
  File f = new File(cwd,filename);
  String info;
  if(!f.exists())
    throw new IllegalArgumentException("Filebrowser.show_info():" + "no such file or directory");

  if(f.isDirectory()) info = "Directory:";
  else info = "File:";

  info+=filename+" ";

  info+=(f.canRead()?"read" : "   ")+(f.canWrite()?"write" : "    ")+f.length() + " " + new java.util.Date(f.lastModified());

  infoarea.setText(info);

}

//this method handles the buttons and list events.

public boolean action(Event e,Object arg)
{
  if(e.target == close) this.dispose();
  else if(e.target == parent)
   {
    String parent = cwd.getParent();
       if(parent == null) parent = "/";

        try {list_directory(parent);}
        catch(IllegalArgumentException ex){infoarea.setText("Already at Top");}
        catch(IOException ex) {infoarea.setText("I/O Error");}
         return true;
}

  else if(e.target == list)
   {
     //when and item is selected, show its info.

    if(e.id == Event.LIST_SELECT)
      {
         try {show_info(entries[((Integer)e.arg).intValue()]);}
         catch(IOException ex) {infoarea.setText("I/O Error");}
      }


//when user double-clicks,change to selected directory or display the selected file.

  else if(e.id == Event.ACTION_EVENT)
   {
    try{
        String item = new File(cwd,(String)e.arg).getAbsolutePath();
        try {list_directory(item);}

        catch(IllegalArgumentException ex) {new fileview2(item);}
       }
    catch(IOException ex){ infoarea.setText("I/O Error");}
   }
return true;
}
return false;
//super.handleEvent(e);
}


public static void usage()
{
  System.out.println("Usage: java Filebrowser[directory_name]" + "[-e file_extension]");
  System.exit(0);

}


// Parse command line arguments and create the Filebrowser object
// if an extension is specified, create a FilenameFilter for it
// if no directory is specified, use the current directory

public static void main(String args[]) throws IOException
{
  Filebrowser f;
  FilenameFilter filter = null;
  String directory = null;


  for(int i=0;i<args.length;i++)
 {
 if(args[i].equals("-e"))
{
  i++;
  if(i>=args.length) usage();
  filter = new EndsWithFilter(args[i]);
}

else
{
  if(directory !=null) usage();
  else directory = args[i];
}
}


//if no directory specified use the current directory


if(directory ==null) directory = System.getProperty("user.dir");

//create the Filebrowser object

f = new Filebrowser(directory,filter);
}

}

//A Filename filter


class EndsWithFilter implements FilenameFilter
{
private String extension;
public EndsWithFilter(String extension)
{
this.extension = extension;
}

public boolean accept(File dir,String name)
{
if(name.endsWith(extension)) return true;
else
return(new File(dir,name)).isDirectory();
}



}











































































